==> haskell-placeholders-0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: placeholders
version: 0.1
id: placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK
key: placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK
license: BSD3
copyright: (c) 2011 Andreas Hammar
maintainer: Andreas Hammar <ahammar@gmail.com>
homepage: http://github.com/ahammar/placeholders
synopsis: Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.
    .
    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>
category: Development
author: Andreas Hammar
exposed: True
indefinite: False
exposed-modules:
    Development.Placeholders
abi: 4a45509e925c807cc175c7ff06a67be6
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/placeholders-0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/placeholders-0.1
hs-libraries: HSplaceholders-0.1-AcMEEx4Dnjq6E1aKP18QcK
depends:
    base-4.10.0.0 template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
haddock-interfaces: /usr/share/doc/haskell-placeholders/html/placeholders.haddock
haddock-html: /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-placeholders-0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: placeholders
version: 0.1
id: placeholders-0.1-7BdB7sfQOem1gBmR2N4Uyl
key: placeholders-0.1-7BdB7sfQOem1gBmR2N4Uyl
license: BSD3
copyright: (c) 2011 Andreas Hammar
maintainer: Andreas Hammar <ahammar@gmail.com>
homepage: http://github.com/ahammar/placeholders
synopsis: Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.
    .
    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>
category: Development
author: Andreas Hammar
exposed: True
indefinite: False
exposed-modules:
    Development.Placeholders
abi: a565c254eaaf778ca845d18a4aad88e0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/placeholders-0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/placeholders-0.1
hs-libraries: HSplaceholders-0.1-7BdB7sfQOem1gBmR2N4Uyl
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-placeholders/html/placeholders.haddock
haddock-html: /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
